.. image:: https://github.com/timoludwig/sphinxcontrib-django2/workflows/Tests/badge.svg
    :alt: GitHub Workflow Status
    :target: https://github.com/timoludwig/sphinxcontrib-django2/actions?query=workflow%3ATests
.. image:: https://img.shields.io/pypi/v/sphinxcontrib-django2.svg
    :alt: PyPi
    :target: https://pypi.org/project/sphinxcontrib-django2/
.. image:: https://codecov.io/gh/timoludwig/sphinxcontrib-django2/branch/develop/graph/badge.svg
    :alt: Code coverage
    :target: https://codecov.io/gh/timoludwig/sphinxcontrib-django2
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :alt: Black Code Style
    :target: https://github.com/psf/black
.. image:: https://img.shields.io/github/license/timoludwig/sphinxcontrib-django2
    :alt: GitHub license
    :target: https://github.com/timoludwig/sphinxcontrib-django2/blob/develop/LICENSE
.. image:: https://readthedocs.org/projects/sphinxcontrib-django2/badge/?version=latest
    :alt: Documentation Status
    :target: https://sphinxcontrib-django2.readthedocs.io/en/latest/?badge=latest

|

.. image:: https://raw.githubusercontent.com/timoludwig/sphinxcontrib-django2/main/docs/images/django-sphinx-logo-blue.png
    :width: 500
    :alt: logo
    :target: https://pypi.org/project/sphinxcontrib-django2/

sphinxcontrib-django2
=====================

This is a sphinx extension which improves the documentation of Django apps.

This was a fork of `sphinxcontrib-django`_, but all changes have been merged into the upstream repository.

.. _sphinxcontrib-django: https://github.com/edoburu/sphinxcontrib-django


Installation
------------

Install the upstream package via pip:

.. code-block:: bash

    pip install sphinxcontrib-django
